==> mysql-admin_1.0.18.orig.tar.gz: mysql-administrator-1.0.18/mysql-administrator/library/tests/test_make_backup/r/mysql_41_utf8.backup.etalon.sql <==
-- MySQL-Administrator dump 1.3
--
-- ------------------------------------------------------
-- Server version	4.1.7-nt


SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT;
SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS;
SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION;
SET NAMES utf8;

/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE=NO_AUTO_VALUE_ON_ZERO */;


CREATE DATABASE /*!32312 IF NOT EXISTS*/ `test`;
USE `test`;

DROP TABLE IF EXISTS `таблица1`;
CREATE TABLE `таблица1` (
  `поле1` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

/*!40000 ALTER TABLE `таблица1` DISABLE KEYS */;
LOCK TABLES `таблица1` WRITE;
INSERT INTO `таблица1` VALUES  ('значение 1'),
 ('значение 2'),
 ('значение 3');
UNLOCK TABLES;

/*!40000 ALTER TABLE `таблица1` ENABLE KEYS */;

DROP TABLE IF EXISTS `таблица2`;
CREATE TABLE `таблица2` (
  `поле2` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

/*!40000 ALTER TABLE `таблица2` DISABLE KEYS */;
LOCK TABLES `таблица2` WRITE;
INSERT INTO `таблица2` VALUES  ('значение 4'),
 ('значение 5');
UNLOCK TABLES;

/*!40000 ALTER TABLE `таблица2` ENABLE KEYS */;
/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT;
SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS;
SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;

==> mysql-admin_1.1.10.orig.tar.gz: mysql-administrator-1.1.10/mysql-administrator/library/tests/test_make_backup/r/mysql_41_utf8.backup.etalon.sql <==
-- MySQL-Administrator dump 1.3
--
-- ------------------------------------------------------


SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT;
SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS;
SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION;
SET NAMES utf8;

/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;


CREATE DATABASE /*!32312 IF NOT EXISTS*/ `test`;
USE `test`;

DROP TABLE IF EXISTS `таблица1`;
CREATE TABLE `таблица1` (
  `поле1` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

/*!40000 ALTER TABLE `таблица1` DISABLE KEYS */;
LOCK TABLES `таблица1` WRITE;
INSERT INTO `таблица1` VALUES  ('значение 1'),
 ('значение 2'),
 ('значение 3');
UNLOCK TABLES;

/*!40000 ALTER TABLE `таблица1` ENABLE KEYS */;

DROP TABLE IF EXISTS `таблица2`;
CREATE TABLE `таблица2` (
  `поле2` varchar(50) collate utf8_bin default NULL
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

/*!40000 ALTER TABLE `таблица2` DISABLE KEYS */;
LOCK TABLES `таблица2` WRITE;
INSERT INTO `таблица2` VALUES  ('значение 4'),
 ('значение 5');
UNLOCK TABLES;

/*!40000 ALTER TABLE `таблица2` ENABLE KEYS */;
/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT;
SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS;
SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
